from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Trigger:
	"""Trigger commands group definition. 22 total commands, 3 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trigger", core, parent)

	@property
	def multiEval(self):
		"""multiEval commands group. 2 Sub-classes, 8 commands."""
		if not hasattr(self, '_multiEval'):
			from .Trigger_.MultiEval import MultiEval
			self._multiEval = MultiEval(self._core, self._base)
		return self._multiEval

	@property
	def prach(self):
		"""prach commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_prach'):
			from .Trigger_.Prach import Prach
			self._prach = Prach(self._core, self._base)
		return self._prach

	@property
	def srs(self):
		"""srs commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_srs'):
			from .Trigger_.Srs import Srs
			self._srs = Srs(self._core, self._base)
		return self._srs

	def clone(self) -> 'Trigger':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Trigger(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
